/* -*- Mode:C; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella <vasta@ragnu.it>
 */
 
 #include <lupin/lupin.h>
 #include "config.h"
 
 l_int32 main(l_int32 argc,l_char *argv[])
{
	if(argc != 1)
		l_std_err("usage: ragnutools");
	else
		l_std_out("Author:Guastella Marco alias vasta\nhome page:http://www.ragnu.it\ncontact:vasta@ragnu.it\nversion:%s\nlicence:GPL3\n",VERSION);
	return 0;
}
